/*
    OGLSL Implementation: Per Fragment Lighting
                          uses 1st OpenGL light source

    (c) 2004 by Martin Christen. All Rights Reserved.
*/

varying vec3 N;
varying vec3 P;

uniform sampler2D myTexture;

void main (void)
{ 
  vec3 L = normalize(gl_LightSource[0].position.xyz-P);

  vec3 diffuse = gl_LightSource[0].diffuse.rgb * max(dot(N,L), 0.0);

  half3 p = P;
  half3 l1 = gl_LightSource[1].position.xyz;
  half3 l2 = gl_LightSource[2].position.xyz;
  half3 l3 = gl_LightSource[3].position.xyz;

  half3 c1 = gl_LightSource[1].diffuse.rgb;
  half3 c2 = gl_LightSource[1].diffuse.rgb;
  half3 c3 = gl_LightSource[1].diffuse.rgb;

  // light source 1
  half3 dist_1 = l1 - p;
  half atten1 = max(1 - dot(dist_1, dist_1) * 0.00099, 0);
  half3 light1 =  c1 * atten1;

  // light source 2
  half3 dist_2 = l2 - p;
  half atten2 = max(1 - dot(dist_2, dist_2) * 0.00099, 0);
  half3 light2 =  c2 * atten2;

  // light source 2
  half3 dist_3 = l3 - p;
  half atten3 = max(1 - dot(dist_3, dist_3) * 0.00099, 0);
  half3 light3 =  c3 * atten3;

  half3 sum = light1 + light2 + light3 ;

  gl_FragColor.rgb =  (gl_LightModel.ambient.xyz + diffuse + sum /*+ light4 + light5*/)
    *  texture2D(myTexture, vec2(gl_TexCoord[0]));
  gl_FragColor.a = 1;

}


